aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--bpkg/system-package-manager-archive.cxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/bpkg/system-package-manager-archive.cxx b/bpkg/system-package-manager-archive.cxx
index 53ef481..0df4580 100644
--- a/bpkg/system-package-manager-archive.cxx
+++ b/bpkg/system-package-manager-archive.cxx
@@ -438,9 +438,10 @@ namespace bpkg
add ("private=" + (priv ? pn.string () : "[null]"));
// If this is a C-based language, add rpath for private installation.
//
- if (priv && (lang_c || lang_cxx || lang_cc))
+ if (priv && (lang_c || lang_cxx || lang_cc) && c != "windows")
{
dir_path l ((dir_path (root) /= "lib") /= pn.string ());
config.push_back ("config.bin.rpath='" + l.representation () + '\'');
@@ -438,9 +438,10 @@ namespace bpkg
add ("private=" + (priv ? pn.string () : "[null]"));
- // If this is a C-based language, add rpath for private installation.
+ // If this is a C-based language, add rpath for private installation,
+ // unless targeting Windows.
//